@@ -35,7 +35,7 @@ def get_customer_profile_ids() -> list[int]:
     """
     Returns a list of all customer profile ids in Authorizenet.
 
-    :raises ValueError: If something goes wrong calling the Authorizenet API.
+    :raises ControllerExecutionError: If the API call fails.
     :returns: A list of all customer profile ids in Authorizenet.
     :rtype: :py:obj:`list`
 
@@ -56,6 +56,33 @@ def get_customer_profile_ids() -> list[int]:
     return [int(id) for id in response.ids.getchildren()]
 
 
+def get_customer_profile_id(email: str) -> int | None:
+    """
+    Retrieves an Authorizenet customer profile id by email address.
+
+    :param email: A customer email address.
+    :type email: :py:obj:`str`
+    :raises ControllerExecutionError: If something goes wrong with the Authorizenet API.
+    :returns: A customer profile id, if found.
+    :rtype: :py:obj:`int` | :py:obj:`None`
+
+    """
+    request = apicontractsv1.getCustomerProfileRequest(
+        merchantAuthentication=get_merchant_auth(), email=email, includeIssuerInfo=False
+    )
+    controller = apicontrollers.getCustomerProfileController(request)
+    controller.setenvironment(get_environment())
+    controller.execute()
+    response = controller.getresponse()
+
+    if response is not None and response.messages.resultCode != "Ok":
+        raise ControllerExecutionError(
+            message=response.messages.message[0]["text"].text,
+            code=response.messages.message[0]["code"].text,
+        )
+    return int(response.profile.customerProfileId)
+
+
 def generate_customer_address(form: forms.Form) -> apicontractsv1.customerAddressType:
     """Takes a form and returns a :py:obj:`~authorizenet.apicontractsv1.customerAddressType`."""
     address: apicontractsv1.customerAddressType = form.cleaned_data["address"]
